==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/et-EE/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Asukohtadest',
    'about_locations'           => 'Asukohti kasutatakse selleks, et jälgida kasutajate, vahendite ja muude asjade liikumist',
    'assets_rtd'                => 'Vahendid', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Väljastatud vahendid',
    'id'                        => 'ID',
    'city'                      => 'Linn',
    'state'                     => 'Maakond',
    'country'                   => 'Riik',
    'create'                    => 'Uus asukoht',
    'update'                    => 'Uuenda asukohta',
    'print_assigned'            => 'Print Assigned',
    'print_all_assigned'        => 'Prindi kõik varad',
    'name'                      => 'Asukoha nimi',
    'address'                   => 'Aadress',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'Postiindeks',
    'locations'                 => 'Asukohad',
    'parent'                    => 'Vanem',
    'currency'                  => 'Asukoha valuuta',
    'ldap_ou'                   => 'LDAP Search OU',
    'user_name'                 => 'Kasutajanimi',
    'department'                => 'Osakond',
    'location'                  => 'Asukoht',
    'asset_tag'                 => 'Vahendite sildid',
    'asset_name'                => 'Nimi',
    'asset_category'            => 'Kategooria',
    'asset_manufacturer'        => 'Tootja',
    'asset_model'               => 'Mudel',
    'asset_serial'              => 'Seerianumber',
    'asset_location'            => 'Asukoht',
    'asset_checked_out'         => 'Väljastatud',
    'asset_expected_checkin'    => 'Eeldatav tagastus',
    'date'                      => 'Kuupäev:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Allkiri (varaaudiitor):',
    'signed_by_finance_auditor' => 'Allkiri (finantsaudiitor):',
    'signed_by_location_manager' => 'Allkiri (asukohahaldur):',
    'signed_by'                 => 'Allkiri:',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/et-EE/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Asukohtadest',
    'about_locations'           => 'Asukohti kasutatakse selleks, et jälgida kasutajate, vahendite ja muude asjade liikumist',
    'assets_rtd'                => 'Vahendid', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Väljastatud vahendid',
    'id'                        => 'ID',
    'city'                      => 'Linn',
    'state'                     => 'Maakond',
    'country'                   => 'Riik',
    'create'                    => 'Uus asukoht',
    'update'                    => 'Uuenda asukohta',
    'print_assigned'            => 'Prindi määratud',
    'print_inventory'           => 'Print Inventory',
    'print_all_assigned'        => 'Print Inventory and Assigned',
    'name'                      => 'Asukoha nimi',
    'address'                   => 'Aadress',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'Postiindeks',
    'locations'                 => 'Asukohad',
    'parent'                    => 'Vanem',
    'currency'                  => 'Asukoha valuuta',
    'ldap_ou'                   => 'LDAP Search OU',
    'user_name'                 => 'Kasutajanimi',
    'department'                => 'Osakond',
    'location'                  => 'Asukoht',
    'asset_tag'                 => 'Vahendite sildid',
    'asset_name'                => 'Nimi',
    'asset_category'            => 'Kategooria',
    'asset_manufacturer'        => 'Tootja',
    'asset_model'               => 'Mudel',
    'asset_serial'              => 'Seerianumber',
    'asset_location'            => 'Asukoht',
    'asset_checked_out'         => 'Väljastatud',
    'asset_expected_checkin'    => 'Eeldatav tagastus',
    'date'                      => 'Kuupäev:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Allkiri (varaaudiitor):',
    'signed_by_finance_auditor' => 'Allkiri (finantsaudiitor):',
    'signed_by_location_manager' => 'Allkiri (asukohahaldur):',
    'signed_by'                 => 'Allkiri:',
    'clone'  					=> 'Clone Location',
];
